# Copyright 2021 Le Filament (<http://www.le-filament.com>)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import fields, models


class PartnerType(models.Model):
    _name = "res.partner.type"
    _description = "Type de contact"

    name = fields.Char("Type", required=True)
    partner_type = fields.Selection(
        string="Type de contact",
        selection=[
            ("person", "Particulier"),
            ("company", "Société"),
            ("all", "Tous"),
        ],
        required=True,
    )
    subtype_ids = fields.One2many(
        comodel_name="res.partner.subtype",
        inverse_name="parent_type_id",
        string="Sous-type",
        required=False,
    )


class PartnerSubtype(models.Model):
    _name = "res.partner.subtype"
    _description = "Sous-Type de contact"

    name = fields.Char("Sous-type", required=True)
    parent_type_id = fields.Many2one(
        comodel_name="res.partner.type", string="Type du parent", required=True
    )


class PartnerCommerceType(models.Model):
    _name = "res.partner.commerce.type"
    _description = "Type de commerce"

    name = fields.Char("Type de commerce", required=True)


class PartnerLegalStatus(models.Model):
    _name = "res.partner.legal.status"
    _description = "Forme jurdique du contact"

    name = fields.Char("Forme juridique", required=True)


class PartnerPrescriteur(models.Model):
    _name = "res.partner.prescripteur"
    _description = "Prescripteur ETIC"

    name = fields.Char("Type", required=True)


class PartnerParticipation(models.Model):
    _name = "res.partner.participation"
    _description = "Activités / Événements"

    name = fields.Char("Activité", required=True)
